package com.amms.service;

import java.util.List;
import com.amms.domain.MuseumIntro;

/**
 * 博物馆简介Service接口
 */
public interface IMuseumIntroService {
    /**
     * 查询博物馆简介列表
     *
     * @param museumIntro 博物馆简介
     * @return 博物馆简介集合
     */
    public List<MuseumIntro> selectMuseumIntroList(MuseumIntro museumIntro);

    /**
     * 查询博物馆简介
     *
     * @param museumName 博物馆简介主键
     * @return 博物馆简介
     */
    public MuseumIntro selectMuseumIntroByMuseumName(String museumName);

    /**
     * 新增博物馆简介
     *
     * @param museumIntro 博物馆简介
     * @return 结果
     */
    public int insertMuseumIntro(MuseumIntro museumIntro);

    /**
     * 修改博物馆简介
     *
     * @param museumIntro 博物馆简介
     * @return 结果
     */
    public int updateMuseumIntro(MuseumIntro museumIntro);

    /**
     * 删除博物馆简介信息
     *
     * @param museumName 博物馆简介主键
     * @return 结果
     */
    public int deleteMuseumIntroByMuseumName(String museumName);
}
